@@ -118,7 +118,7 @@ int main(int argc, char *argv[])
    /* --------------------------------- */
    
    
-   MESSAGE(11,fp=fopen("TestZa_c.txtout","w"););
+   MESSAGE(11,fp=fopen("TestZa.txt","w"););
    MESSAGE(4,printf("Testing ZA C interface \n"););
    MESSAGE(4,printf("=========================\n\n"););
    MESSAGE(11,fprintf(fp,"Testing ZA C interface \n"););
